SystemOrganization addCategory: 'ConfigurationOfSqueakSource'!

Object subclass: #ConfigurationOfSqueakSource
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSqueakSource'!

!ConfigurationOfSqueakSource commentStamp: 'topa 4/21/2011 08:51' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '3.0-beta.1'
               for: 'SqueakSource'
                importFromBaseline: '3.0-beta.1-baseline'
                description: 'Split out Monticello. Pick up SeasideRest 0.20'.
!

!ConfigurationOfSqueakSource class methodsFor: 'private' stamp: 'topa 3/14/2011 22:08'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].! !

!ConfigurationOfSqueakSource class methodsFor: 'private' stamp: 'topa 6/21/2010 16:47'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSqueakSource class methodsFor: 'private' stamp: 'topa 3/14/2011 22:07'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSqueakSource class methodsFor: 'private' stamp: 'topa 3/14/2011 22:07'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSqueakSource class methodsFor: 'metacello tool support' stamp: 'topa 6/21/2010 16:47'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSqueakSource class methodsFor: 'metacello tool support' stamp: 'topa 6/21/2010 16:47'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSqueakSource class methodsFor: 'loading' stamp: 'topa 3/14/2011 22:08'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSqueakSource class methodsFor: 'loading' stamp: 'topa 3/14/2011 22:08'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSqueakSource class methodsFor: 'loading' stamp: 'topa 3/14/2011 22:08'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSqueakSource class methodsFor: 'metacello tool support' stamp: 'topa 6/21/2010 16:47'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSqueakSource class methodsFor: 'accessing' stamp: 'topa 3/14/2011 22:08'!
project

	^self new project! !

!ConfigurationOfSqueakSource class methodsFor: 'unloading Metacello' stamp: 'topa 6/21/2010 16:47'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSqueakSource class methodsFor: 'development' stamp: 'topa 3/14/2011 22:09'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 6/25/2010 12:25'!
baseline30alpha1: spec 
	<version: '3.0-alpha.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec repository: 'http://www.squeaksource.com/squeaksource3'.
		spec 
			package: 'SqueakSource' with: [ spec requires: #('Seaside30' 'Magritte2 Seaside' 'Magritte2 Tests' 'TinyWiki')];
			package: 'TinyWiki' with: [spec requires: #('Seaside30' 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #('SqueakSource');
			yourself.
		spec
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					versionString: '3.0.0-alpha5.15';
					loads: #('Core');
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Core' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					versionString: '2.0.5';
					loads: #('Core');
					file: 'ConfigurationOfMagritte2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Magritte2 Seaside' copyFrom: 'Magritte2 Core' with: [
				spec
					loads: #( 'Magritte-Seaside' ).];
			project: 'Magritte2 Tests' copyFrom: 'Magritte2 Core' with: [
				spec
					loads: #( 'Tests' ).];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					versionString: '0.1';
					file: 'ConfigurationOfSmaCC';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		"From ConfigurationOfGsSqueakSource"
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SMTPMail' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SMTPMail';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			package: 'SqueakSource' with: [ 
				spec requires: #('Seaside30' 'Magritte2 Seaside' 'Magritte2 Tests' 'SMTPMail' 'TinyWiki')];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'DaleHenrichs 07/06/2010 20:11'!
baseline30alpha3: spec 
	<version: '3.0-alpha.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras')];
			package: 'SqueakSource-Tests' with: [ spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #('SqueakSource-Core');
			group: 'Tests' with: #('SqueakSource-Tests');
			yourself.
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					file: 'ConfigurationOfMagritte2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-Pharo-Core')];
			package: 'SqueakSource-Pharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ spec requires: #('SqueakSource-Core')];
			yourself.
		spec
			group: 'Core' with: #('SqueakSource-Storage-FileSystem');
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-GemStone-Core')];
			package: 'SqueakSource-GemStone-Core' with: [ 
				spec 
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: #('SqueakSource-Core')];
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'DaleHenrichs 07/11/2010 12:09'!
baseline30alpha4: spec 
	<version: '3.0-alpha.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST')];
			package: 'SqueakSource-Issues' with: [ 
					spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Tests' with: [ spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #('SqueakSource-Core' 'SqueakSource-Issues');
			group: 'Tests' with: #('SqueakSource-Tests');
			yourself.
		spec
			package: 'Seaside-REST' with: [spec
				requires: #('Seaside Extras');
				repository: 'http://www.squeaksource.com/Seaside30Addons'].
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Email' 'RSS-Core' 'Seaside-Tests-Core'); "'Seaside-Tests-Core' needed since Seaside-REST tests aren't split out separately"
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					file: 'ConfigurationOfMagritte2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-Pharo-Core')];
			package: 'SqueakSource-Pharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ spec requires: #('SqueakSource-Core')];
			yourself.
		spec
			group: 'Core' with: #('SqueakSource-Storage-FileSystem');
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'Seaside-REST' with: [ spec file: 'Seaside-REST.gemstone' ];
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-GemStone-Core')];
			package: 'SqueakSource-GemStone-Core' with: [ 
				spec 
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: #('SqueakSource-Core')];
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 3/14/2011 23:09'!
baseline30alpha5: spec 
	<version: '3.0-alpha.5-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST-Core')];
			package: 'SqueakSource-Issues' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Core' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Dictionary' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Subscription-Core' with: [ 
				spec requires: #('SqueakSource-Core')];			
			package: 'SqueakSource-Subscription-Email' with: [ 
				spec requires: #('SqueakSource-Subscription-Core')];			
			package: 'SqueakSource-Tests' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Standard');
			group: 'Minimal' with: #('SqueakSource-Core' 'SqueakSource-Storage-Dictionary');
			group: 'Standard' with: #('Minimal' 'SqueakSource-Storage-FileSystem' 'SqueakSource-Statistics' 'SqueakSource-Issues');
			group: 'Full' with: #('Standard' 'SqueakSource-Subscription-Email');
			group: 'Tests' with: #('SqueakSource-Tests');
			group: 'All' with: #('Full' 'Tests');
			yourself.
		spec
			package: 'Seaside-REST-Core' with: [spec
				requires: #('Seaside Extras');
				repository: 'http://www.squeaksource.com/Seaside30Addons'].
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'Seaside-REST-Core' with: [ spec includes: #('Seaside-Pharo-REST-Core') ];
			package: 'Seaside-Pharo-REST-Core' with: [
				spec
					requires: #('Seaside-REST-Core');
					repository: 'http://www.squeaksource.com/Seaside30Addons'];
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Core')];
			package: 'SqueakSource-SqueakPharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ spec includes: #('SqueakSource-SqueakPharo-Statistics')];
			package: 'SqueakSource-SqueakPharo-Statistics' with: [ spec requires: #('SqueakSource-Statistics')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Storage-Core')];
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'Seaside-REST-Core' with: [ spec includes: #('Seaside-GemStone-REST-Core') ];
			package: 'Seaside-GemStone-REST-Core' with: [
				spec
					requires: #('Seaside-REST-Core');
					repository: 'http://www.squeaksource.com/Seaside30Addons'];
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-GemStone-Core')];
			package: 'SqueakSource-GemStone-Core' with: [ 
				spec 
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: #('SqueakSource-Core')];
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 04/07/2011 12:54'!
baseline30alpha7: spec 
	<version: '3.0-alpha.7-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST')];
			package: 'SqueakSource-Issues' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Core' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Dictionary' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Subscription-Core' with: [ 
				spec requires: #('SqueakSource-Core')];			
			package: 'SqueakSource-Subscription-Email' with: [ 
				spec requires: #('SqueakSource-Subscription-Core')];			
			package: 'SqueakSource-Tests' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Standard');
			group: 'Minimal' with: #('SqueakSource-Core' 'SqueakSource-Storage-Dictionary');
			group: 'Standard' with: #('Minimal' 'SqueakSource-Storage-FileSystem' 'SqueakSource-Statistics' 'SqueakSource-Issues');
			group: 'Full' with: #('Standard' 'SqueakSource-Subscription-Email');
			group: 'Tests' with: #('SqueakSource-Tests');
			group: 'All' with: #('Full' 'Tests');
			yourself.
		spec
			project: 'Seaside-REST' with: [spec
				className: 'ConfigurationOfSeasideRest';
				versionString: '0.19';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					versionString: '3.0.4';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					versionString:  '2.0.6';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					versionString: '0.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Core')];
			package: 'SqueakSource-SqueakPharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ spec includes: #('SqueakSource-SqueakPharo-Statistics')];
			package: 'SqueakSource-SqueakPharo-Statistics' with: [ spec requires: #('SqueakSource-Statistics')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Storage-Core')];
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					versionString: '0.241';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					versionString: '0.238';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'SqueakSource-GemStone-Core' with: [ 
				spec 
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: #('SqueakSource-Core')];
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				 spec 
					includes: #('SqueakSource-GemStone-Core');
					requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 04/07/2011 13:39'!
baseline30alpha9: spec 
	<version: '3.0-alpha.9-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST')];
			package: 'SqueakSource-Issues' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Core' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Dictionary' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Subscription-Core' with: [ 
				spec requires: #('SqueakSource-Core')];			
			package: 'SqueakSource-Subscription-Email' with: [ 
				spec requires: #('SqueakSource-Subscription-Core')];			
			package: 'SqueakSource-Tests' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Standard');
			group: 'Minimal' with: #('SqueakSource-Core' 'SqueakSource-Storage-Dictionary');
			group: 'Standard' with: #('Minimal' 'SqueakSource-Storage-FileSystem' 'SqueakSource-Statistics' 'SqueakSource-Issues');
			group: 'Full' with: #('Standard' 'SqueakSource-Subscription-Email');
			group: 'Tests' with: #('SqueakSource-Tests');
			group: 'All' with: #('Full' 'Tests');
			yourself.
		spec
			project: 'Seaside-REST' with: [spec
				className: 'ConfigurationOfSeasideRest';
				versionString: '0.19';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					versionString: '3.0.4';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					versionString:  '2.0.6';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					versionString: '0.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Core')];
			package: 'SqueakSource-SqueakPharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ spec includes: #('SqueakSource-SqueakPharo-Statistics')];
			package: 'SqueakSource-SqueakPharo-Statistics' with: [ spec requires: #('SqueakSource-Statistics')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Storage-Core')];
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					versionString: '0.241';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					versionString: '0.238';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'SqueakSource-GemStone-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-GemStone-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-GemStone-Statistics' with: [
				spec
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: 'SqueakSource-Statistics'];
				
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				 spec 
					includes: #('SqueakSource-GemStone-Core');
					requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: 'SqueakSource-GemStone-Storage-Core'];
			package: 'SqueakSource-Statistics' with: [ spec includes: 'SqueakSource-GemStone-Statistics'];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 4/21/2011 08:50'!
baseline30beta1: spec 
	<version: '3.0-beta.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST')];
			package: 'SqueakSource-Monticello-Core' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Issues' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Core' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Dictionary' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Subscription-Core' with: [ 
				spec requires: #('SqueakSource-Core')];			
			package: 'SqueakSource-Subscription-Email' with: [ 
				spec requires: #('SqueakSource-Subscription-Core')];			
			package: 'SqueakSource-Tests' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Standard');
			group: 'Minimal' with: #('SqueakSource-Core' 'SqueakSource-Monticello-Core' 'SqueakSource-Storage-Dictionary');
			group: 'Standard' with: #('Minimal' 'SqueakSource-Storage-FileSystem' 'SqueakSource-Statistics' 'SqueakSource-Issues');
			group: 'Full' with: #('Standard' 'SqueakSource-Subscription-Email');
			group: 'Tests' with: #('SqueakSource-Tests');
			group: 'All' with: #('Full' 'Tests');
			yourself.
		spec
			project: 'Seaside-REST' with: [spec
				className: 'ConfigurationOfSeasideRest';
				versionString: '0.20';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Base' 'Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					versionString: '3.0.4';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					versionString:  '2.0.6';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					versionString: '0.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Core')];
			package: 'SqueakSource-SqueakPharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ spec includes: #('SqueakSource-SqueakPharo-Statistics')];
			package: 'SqueakSource-SqueakPharo-Statistics' with: [ spec requires: #('SqueakSource-Statistics')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Storage-Core')];
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					versionString: '0.241';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					versionString: '0.238';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'SqueakSource-GemStone-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-GemStone-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-GemStone-Statistics' with: [
				spec
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: 'SqueakSource-Statistics'];
				
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				 spec 
					includes: #('SqueakSource-GemStone-Core');
					requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: 'SqueakSource-GemStone-Storage-Core'];
			package: 'SqueakSource-Statistics' with: [ spec includes: 'SqueakSource-GemStone-Statistics'];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'baselines' stamp: 'topa 5/24/2011 16:43'!
baseline30beta2: spec 
	<version: '3.0-beta.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'SqueakSource is a smart Monticello code-repository for Squeak. It allows to define projects easily and set-up access rights for developers and users.'.
            spec author: 'topa'.
		spec 
			repository: 'http://www.squeaksource.com/squeaksource3';
			repository: 'http://seaside.gemstone.com/ss/squeaksource3'.
		spec 
			package: 'SqueakSource-Core' with: [ 
				spec requires: #('Magritte2 Seaside' 'TinyWiki' 'Seaside Extras' 'Seaside-REST')];
			package: 'SqueakSource-Monticello-Core' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Issues' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Statistics' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Core' with: [ 
				spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Storage-Dictionary' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Storage-FileSystem' with: [ 
				spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Subscription-Core' with: [ 
				spec requires: #('SqueakSource-Core')];			
			package: 'SqueakSource-Subscription-Email' with: [ 
				spec requires: #('SqueakSource-Subscription-Core')];			
			package: 'SqueakSource-Gravatar' with: [
				spec requires: #('Gravatar' 'SqueakSource-Core')];
			package: 'SqueakSource-Tests' with: [
				spec requires: #('SqueakSource-Core')];
			package: 'TinyWiki' with: [spec requires: #( 'SmaCC')];
			yourself.
		spec
			group: 'default' with: #('Standard');
			group: 'Minimal' with: #('SqueakSource-Core' 'SqueakSource-Monticello-Core' 'SqueakSource-Storage-Dictionary');
			group: 'Standard' with: #('Minimal' 'SqueakSource-Storage-FileSystem' 'SqueakSource-Statistics' 'SqueakSource-Issues');
			group: 'Full' with: #('Standard' 'SqueakSource-Subscription-Email' 'SqueakSource-Gravatar');
			group: 'Tests' with: #('SqueakSource-Tests');
			group: 'All' with: #('Full' 'Tests');
			yourself.
		spec
			project: 'Gravatar' with: [
				spec
					className: 'ConfigurationOfGravatar';
					file: 'ConfigurationOfGravatar';
					versionString:  '1.0';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Seaside-REST' with: [
				spec
					className: 'ConfigurationOfSeasideRest';
					versionString: '0.20';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Seaside Extras' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					loads: #('Base' 'Seaside-Email' 'RSS-Core');
					file: 'ConfigurationOfSeaside30';
					versionString: '3.0.4';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			project: 'Magritte2 Seaside' with: [
				spec
					className: 'ConfigurationOfMagritte2';
					loads: #( 'Magritte-Seaside' 'Tests' );
					versionString:  '2.0.6';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself].
	spec for: #squeakCommon do: [
		spec
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfSmaCC';
					file: 'ConfigurationOfSmaCC';
					versionString: '0.1';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'SqueakSource-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Core')];
			package: 'SqueakSource-SqueakPharo-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-Monticello-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Monticello')];
			package: 'SqueakSource-SqueakPharo-Monticello' with: [ spec requires: #('SqueakSource-Monticello-Core')];
			package: 'SqueakSource-Statistics' with: [ spec includes: #('SqueakSource-SqueakPharo-Statistics')];
			package: 'SqueakSource-SqueakPharo-Statistics' with: [ spec requires: #('SqueakSource-Statistics')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: #('SqueakSource-SqueakPharo-Storage-Core')];
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			yourself].
	spec for: #squeak do: [
		spec
			preLoadDoIt: #preloadForSqueak;
			yourself].
	spec for: #gemstone do: [
		spec
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					versionString: '0.241';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: 'Monticello';
					file: 'ConfigurationOfGsMonticello';
					versionString: '0.238';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'SmaCC' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'SmaCC';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: 'XML-Parser';
					file: 'ConfigurationOfGsMisc';
					versionString: '0.237';  
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec
			package: 'SqueakSource-GemStone-Core' with: [ spec requires: #('SqueakSource-Core')];
			package: 'SqueakSource-GemStone-Storage-Core' with: [ spec requires: #('SqueakSource-Storage-Core')];
			package: 'SqueakSource-Monticello-Core' with: [ spec includes: #('SqueakSource-Gemstone-Monticello')];
			package: 'SqueakSource-Gemstone-Monticello' with: [ spec requires: #('SqueakSource-Monticello-Core')];
			package: 'SqueakSource-GemStone-Statistics' with: [
				spec
					postLoadDoIt: #postload30alpha3ForGemStone;
					requires: 'SqueakSource-Statistics'];
				
			package: 'MonticelloConfigurations' with: [ 
				spec 
					file: 'MonticelloConfigurations.g';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			package: 'SqueakSource-Core' with: [ 
				 spec 
					includes: #('SqueakSource-GemStone-Core');
					requires: #('XML-Parser' 'MonticelloConfigurations' 'Monticello')];
			package: 'SqueakSource-Storage-Core' with: [ spec includes: 'SqueakSource-GemStone-Storage-Core'];
			package: 'SqueakSource-Statistics' with: [ spec includes: 'SqueakSource-GemStone-Statistics'];
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'symbolic versions' stamp: 'topa 5/5/2011 17:47'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.0-beta.2-baseline'.! !

!ConfigurationOfSqueakSource methodsFor: 'symbolic versions' stamp: 'topa 5/5/2011 17:45'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '3.0-beta.2'.! !

!ConfigurationOfSqueakSource methodsFor: 'symbolic versions' stamp: 'topa 5/5/2011 18:22'!
easterEgg: spec
	<symbolicVersion: #'easterEgg'>

	spec for: #'common' version: '3.0-beta.2'.! !

!ConfigurationOfSqueakSource methodsFor: 'symbolic versions' stamp: 'topa 4/26/2011 10:22'!
easterFire: spec
	<symbolicVersion: #'easterFire'>

	spec for: #'common' version: '3.0-beta.1'.! !

!ConfigurationOfSqueakSource methodsFor: 'doits' stamp: 'DaleHenrichs 07/06/2010 18:28'!
postload30alpha3ForGemStone

 	Smalltalk at: #WAGemStoneMaintenanceTask ifPresent: [:cl | cl buildTaskList]! !

!ConfigurationOfSqueakSource methodsFor: 'doits' stamp: 'topa 10/22/2010 07:47'!
preloadForSqueak

	(self class environment hasClassNamed: #'Announcement')
		ifFalse: [ | installer |
			installer := ((self class environment at: #Installer) perform: #ss).
			installer perform: #project: with: 'AXAnnouncements'. 
			installer perform: #install: with: 'Announcements'. ].! !

!ConfigurationOfSqueakSource methodsFor: 'accessing' stamp: 'topa 3/14/2011 22:06'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'dkh 05/18/2011 00:27'!
verison30alpha1: spec 
	<version: '3.0-alpha.1' imports: #('3.0-alpha.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #alpha.
		spec 
			package: 'SqueakSource' with: 'SqueakSource-topa.1104';
			package: 'TinyWiki' with: 'TinyWiki-lr.18';
			yourself].
	spec for: #gemstone do: [
		spec 
			project: 'SmaCC' with: '0.237';
			project: 'SMTPMail' with: '0.237';
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'dkh 05/18/2011 00:27'!
verison30alpha2: spec 
	<version: '3.0-alpha.2' imports: #('3.0-alpha.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec description: '- cope for some GemStone/Swazoo specialities'.
		spec 
			package: 'SqueakSource' with: 'SqueakSource-topa.1106';
			package: 'TinyWiki' with: 'TinyWiki-lr.18';
			yourself].
	spec for: #gemstone do: [
		spec 
			project: 'SmaCC' with: '0.237';
			project: 'SMTPMail' with: '0.237';
			yourself].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 9/29/2010 22:30'!
verison30alpha3: spec
	<version: '3.0-alpha.3' imports: #('3.0-alpha.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- split SqueakSource into multiple mcz packages
- load only Seaside base + required extras (person loading SqueakSource must choose which adaptor to use)
- fixed static listing url for project to html...
- commented out "google sitemaps verification" in SSFrame>>updateRoot: since it looks suspicious
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '07/02/10 09:24:07'.
		spec 
			project: 'Seaside Extras' with: '3.0.0-alpha5.15';
			project: 'Magritte2 Seaside' with: '2.0.5'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-DaleHenrichs.4';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-DaleHenrichs.1';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'.].
	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-Pharo-Core' with: 'SqueakSource-Pharo-Core-DaleHenrichs.1';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-DaleHenrichs.1'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 9/29/2010 22:29'!
verison30alpha4: spec
	<version: '3.0-alpha.4' imports: #('3.0-alpha.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- use experimental Seaside-REST api
- merge DaleHenrichs and pmm code
- port Seaside-REST to gemstone (passing all tests)
- added support for the following RESTful URL patterns:
  http://localhost:8181/ss/Home
  http://localhost:8181/ss/Projects
  http://localhost:8181/ss/Tags
  http://localhost:8181/ss/Members
  http://localhost:8181/ss/Groups
  http://localhost:8181/ss/Help
  http://localhost:8181/ss/<project name>.html/Overview
  http://localhost:8181/ss/<project name>.html/Wiki
  http://localhost:8181/ss/<project name>.html/News
  http://localhost:8181/ss/<project name>.html/Versions
  http://localhost:8181/ss/<project name>.html/Latest
  http://localhost:8181/ss/<project name>.html/Statistics
	(not really RESTful URLs for the projects, but hey this is my first day doing REST with Seaside)
- add project-based issue tracker (very basic capability). It''s kinda pluggable right now, but if there is interest to include this officially, then I''ll pull the package over to squeak source.
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '07/11/10 12:05:40'.
		spec 
			project: 'Seaside Extras' with: '3.0.0-alpha5.15';
			project: 'Magritte2 Seaside' with: '2.0.5'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-DaleHenrichs.10';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-DaleHenrichs.4';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.2';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'.].
	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'Seaside-REST' with: 'Seaside-REST-pmm.16';
			package: 'SqueakSource-Pharo-Core' with: 'SqueakSource-Pharo-Core-topa.2';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.3'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'Seaside-REST' with: 'Seaside-REST.gemstone-DaleHenrichs.17';
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 3/14/2011 23:15'!
version30alpha5: spec
	<version: '3.0-alpha.5' imports: #('3.0-alpha.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Splitting SqueakSource'.
		spec author: 'topa'.
		spec timestamp: '3/14/2011 21:12'.
		spec 
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.6'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-topa.11';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-topa.5';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.1';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.1';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.4';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.1';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.17';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4';
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.1';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-DaleHenrichs.1';
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 3/16/2011 22:02'!
version30alpha6: spec
	<version: '3.0-alpha.6' imports: #('3.0-alpha.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Pick up Gerhard Obermanns changes.'.
		spec author: 'topa'.
		spec timestamp: '3/15/2011 16:14'.
		spec 
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.6'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-obi.17';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-obi.6';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.1';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.1';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.5';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.2';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'TinyWiki' with: 'TinyWiki-lr.18';
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.17'. ].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.4';
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.1';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'Seaside-GemStone-REST-Core' with: 'Seaside-GemStone-REST-Core-DaleHenrichs.1';
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 3/24/2011 12:14'!
version30alpha7: spec
	<version: '3.0-alpha.7' imports: #('3.0-alpha.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Use the '.
		spec author: 'topa'.
		spec timestamp: '3/15/2011 16:14'.
		spec 
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.6'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-obi.17';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-obi.6';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.1';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.1';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.5';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.2';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.1';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 4/1/2011 17:20'!
version30alpha8: spec
	<version: '3.0-alpha.8' imports: #('3.0-alpha.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Incorporate bf.1070, Changes View and .cs/.diff'.
		spec author: 'topa'.
		spec timestamp: '3/31/2011 21:06'.
		spec 
			project: 'Seaside-REST' with: '0.19';
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.6'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-topa.19';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-obi.6';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.1';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.2';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.8';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.3';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'. ].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.2';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-DaleHenrichs.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'.]! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 4/21/2011 08:59'!
version30alpha9: spec
	<version: '3.0-alpha.9' imports: #('3.0-alpha.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Adaptions to Gemstone'.
		spec author: 'topa'.
		spec timestamp: '04/07/2011 04:40:07'.
		spec 
			project: 'Seaside-REST' with: '0.19';
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.6'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-topa.24';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-topa.7';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.2';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.3';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.8';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.3';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'. ].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.2';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'.  ].


	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'Monticello' with: '0.239.1';
			project: 'SmaCC' with: '0.238';
			project: 'XML-Parser' with: '0.238'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-topa.2';
			package: 'SqueakSource-GemStone-Storage-Core' with: 'SqueakSource-GemStone-Storage-Core-topa.1';
			package: 'SqueakSource-GemStone-Statistics' with: 'SqueakSource-GemStone-Statistics-topa.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'topa 4/21/2011 09:00'!
version30beta1: spec
	<version: '3.0-beta.1' imports: #('3.0-beta.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Split out Monticello. Pick up SeasideRest 0.20'.
		spec author: 'topa'.
		spec timestamp: '4/21/2011 08:51'.
		spec 
			project: 'Seaside-REST' with: '0.20';
			project: 'Seaside Extras' with: '3.0.4';
			project: 'Magritte2 Seaside' with: '2.0.5.1'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-topa.25';
			package: 'SqueakSource-Monticello-Core' with: 'SqueakSource-Monticello-Core-topa.1';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-topa.7';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-topa.2';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.2';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-topa.3';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.8';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-topa.5';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-topa.3';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'. ].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.2';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-topa.4';
			package: 'SqueakSource-GemStone-Storage-Core' with: 'SqueakSource-GemStone-Storage-Core-topa.2';
			package: 'SqueakSource-GemStone-Statistics' with: 'SqueakSource-GemStone-Statistics-topa.1';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'].! !

!ConfigurationOfSqueakSource methodsFor: 'versions' stamp: 'dkh 05/25/2011 11:18'!
version30beta2: spec
	<version: '3.0-beta.2' imports: #('3.0-beta.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'New design. Code browsing on GemStone
3.0-beta.2 (dkh.48):
- pick up tobias'' test changes
- remove UndefinedObject>.isAnonymous
- get diff/cs views working (use  RWBinaryOrTextStream)
- work on change password emal ... still trouble
- clear stats when new repository created
- flush the Magritte cache when generating installWizard

3.0-beta.2 (dkh.50):
- SSInstallWizzard needs to be unregistered once you deploy ... add helper methods for register and unregister 
- change default name
3.0-beta.2 (dkh.51):
- use reduced conflict dictionaries in a few more spots
- add nested dictionary storage .... reduce potential for conflicts
- add tests for SSStorage .... specifically SSDictionaryStorage and SSNestedDictionaryStoreage
3.0-beta.2 (dkh.317):
- got forgotten password continuation working, but need to now set it up so that the user is actually logged in, which isn''t the case at the moment...
- couple of tweaks
3.0-beta.2 (dkh.53):
- login before editMember: call works like a charm ... forgotten password handling is working correctly now ....
3.0-beta.2 (dkh.54):
- use RcCounter for download counts (avoid commit conflicts)
- update stats every 90 minutes
3.0-beta.2 (dkh.55):
- infant mortality on using RcKeyValueDictionaries everywhere...
3.0-beta.2 (dkh.56):
- conflict free logging in SSDictionaryStorage
- make SSNestedDictionaryStorage the default for GemStone
3.0-beta.2 (topa.59):
- pick up Monticello specifics for snapshot browser on Squeak/Pharo
- provide OrderedCollection as Queue on Squeak/Pharo
3.0-beta.2 (dkh.61):
- SSFrame>>style (with empty string) and SSWiki>>style trigger a bug in Seaside that would lead to commit conflicts in GemStone and introduce very poor performance.
- SSRepository stats and cache recalculated once an hour .... for now'.
		spec author: 'dkh'.
		spec timestamp: '05/25/2011 11:18:52'.
		spec 
			project: 'Seaside-REST' with: '0.21';
			project: 'Seaside Extras' with: '3.0.5';
			project: 'Magritte2 Seaside' with: '2.0.6';
			project: 'Gravatar' with: '1.0'.
		spec 
			package: 'SqueakSource-Core' with: 'SqueakSource-Core-dkh.45';
			package: 'SqueakSource-Monticello-Core' with: 'SqueakSource-Monticello-Core-dkh.4';
			package: 'SqueakSource-Issues' with: 'SqueakSource-Issues-topa.7';
			package: 'SqueakSource-Statistics' with: 'SqueakSource-Statistics-dkh.8';
			package: 'SqueakSource-Storage-Core' with: 'SqueakSource-Storage-Core-topa.4';
			package: 'SqueakSource-Storage-Dictionary' with: 'SqueakSource-Storage-Dictionary-dkh.7';
			package: 'SqueakSource-Storage-FileSystem' with: 'SqueakSource-Storage-FileSystem-topa.8';
			package: 'SqueakSource-Subscription-Core' with: 'SqueakSource-Subscription-Core-dkh.7';
			package: 'SqueakSource-Subscription-Email' with: 'SqueakSource-Subscription-Email-topa.1';
			package: 'SqueakSource-Tests' with: 'SqueakSource-Tests-dkh.7';
			package: 'SqueakSource-Gravatar' with: 'SqueakSource-Gravatar-topa.1';
			package: 'TinyWiki' with: 'TinyWiki-lr.18'. ].

	spec for: #'squeakCommon' do: [
		spec project: 'SmaCC' with: '0.1'.
		spec 
			package: 'SqueakSource-SqueakPharo-Core' with: 'SqueakSource-SqueakPharo-Core-topa.2';
			package: 'SqueakSource-SqueakPharo-Monticello' with: 'SqueakSource-SqueakPharo-Monticello-topa.3';
			package: 'SqueakSource-SqueakPharo-Statistics' with: 'SqueakSource-SqueakPharo-Statistics-topa.1';
			package: 'SqueakSource-SqueakPharo-Storage-Core' with: 'SqueakSource-SqueakPharo-Storage-Core-topa.2'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'Monticello' with: '0.238';
			project: 'SmaCC' with: '0.237';
			project: 'XML-Parser' with: '0.237'.
		spec 
			package: 'SqueakSource-GemStone-Core' with: 'SqueakSource-GemStone-Core-dkh.6';
			package: 'SqueakSource-Gemstone-Monticello' with: 'SqueakSource-Gemstone-Monticello-topa.1';
			package: 'SqueakSource-GemStone-Storage-Core' with: 'SqueakSource-GemStone-Storage-Core-dkh.5';
			package: 'SqueakSource-GemStone-Statistics' with: 'SqueakSource-GemStone-Statistics-dkh.6';
			package: 'MonticelloConfigurations' with: 'MonticelloConfigurations.g-dkh.48'. ].! !
